## INTRODUCTION

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! WARNING !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
You must have a Fortran compiler in order to build the ONERA_DESP_LIB distribution.
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
Requests for assistance or documentation should be sent to: sebastien.bourdarie@onera.fr
If you get the distribution, please send to sebastien.bourdarie@onera.fr a message so we can put you on our mailing list. That way you will be notified of new releases.
The use of the Makefile to build the library is highly recommended. Old scripts distributed before are still provided but will not be maintained any more. The new Makefile allows to build the library on various platforms, either 32 or 64 bits computers. It solves the problems being encounter to built the library on new 64 bit linux box and run it with IDL.

## INSTALLATION INSTRUCTIONS

ONERA_DESP_LIB has a makefile setup to automatically build the library. The following steps should be taken to build and install ONERA_DESP_LIB.
1. Set your current directory (cd) to the top level ONERA_DESP_LIB directory.
2. Compile/link the distribution. First enter...
make all.help
For example, to build the distribution on a SunOS system using the gnu Fortran compiler enter...
make OS=sunos ENV=gnu64 all
The `OS' and `ENV' variables are described in the `make all.help' part of this step.
3. Install the libraries. First enter...
make install.help
To determine the required/optional `make' variables to be used.
Then enter...
make `make variables...' install
The appropriate files will be copied to the `matlab' and top level ONERA_DESP_LIB directories (from the `source/...' directory).
For example, to install the distribution in `/usr/local/onera_desp_lib' enter...
make INSTALLDIR=/usr/local/onera_desp_lib install
The `INSTALLDIR' variable is described in the `make install.help' part of this step.
4. Test that the distribution was built correctly.
First enter...
make test.help
To determine the required/optional `make' variables to be used.
Then enter...
make `make variables...' test
The name of each test executed and results will be displayed.
5. Delete the libraries, object files, and executables in the `source/...' directory by entering...
make clean